@@ -11,10 +11,12 @@ namespace bd::Outputs::Wlr {
   }
 
   void Mode::zwlr_output_mode_v1_size(int32_t width, int32_t height) {
+    qDebug() << "Mode size changed to: " << width << "x" << height;
     emit propertyChanged(MetaModeProperty::Property::Size, QVariant {QSize(width, height)});
   }
 
   void Mode::zwlr_output_mode_v1_refresh(int32_t refresh) {
+    qDebug() << "Mode refresh changed to: " << refresh;
     auto val = QVariant::fromValue(refresh);
     emit propertyChanged(MetaModeProperty::Property::Refresh, val);
   }
@@ -22,8 +24,4 @@ namespace bd::Outputs::Wlr {
   void Mode::zwlr_output_mode_v1_preferred() {
     emit propertyChanged(MetaModeProperty::Property::Preferred, QVariant::fromValue(true));
   }
-
-//  void WaylandOutputMode::zwlr_output_mode_v1_finished() {
-//    emit modeFinished();
-//  }
 }
